@@ -841,7 +841,11 @@ impl<'s> AppState<'s> {
         ); // bold, colored background
         let area = Area::new(0, y, self.width - 1, self.page_height() as u16);
         let content_height = self.content_height();
-        let scrollbar = area.scrollbar(self.scroll, content_height);
+        let scrollbar = if self.mission.job.hide_scrollbar() {
+            None
+        } else {
+            area.scrollbar(self.scroll, content_height)
+        };
         let mut top_item_idx = None;
         let top = if self.reverse && self.page_height() > content_height {
             self.page_height() - content_height
